AsyncReadAncillaryMulti

Trait AsyncReadAncillaryMulti 

pub trait AsyncReadAncillaryMulti {
    type Return;

    // Required method
    fn read_multi_with_ancillary(
        &mut self,
        control_len: usize,
    ) -> impl Stream<Item = Result<Self::Return, Error>>;
}
Available on crate features io and ancillary only.
Trait for asynchronous read with ancillary (control) data that returns multiple managed buffers. Intended for connected stream sockets (TCP, Unix streams) where no source address is needed.

Required Associated Types

type Return

A wrapped type for the payload data and the ancillary data.

Required Methods

fn read_multi_with_ancillary( &mut self, control_len: usize, ) -> impl Stream<Item = Result<Self::Return, Error>>

Read data and ancillary data into multiple managed buffers.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors